Struct futures_delay_queue::DelayQueue
source · [−]pub struct DelayQueue<T: 'static, A: RingBuf<Item = T>> { /* private fields */ }Expand description
A queue for managing delayed items.
Implementations
sourceimpl<T, A> DelayQueue<T, A> where
T: 'static + Send,
A: 'static + RingBuf<Item = T> + Send,
impl<T, A> DelayQueue<T, A> where
T: 'static + Send,
A: 'static + RingBuf<Item = T> + Send,
sourcepub fn insert(&self, value: T, dur: Duration) -> DelayHandle
pub fn insert(&self, value: T, dur: Duration) -> DelayHandle
Inserts an item into the delay queue that will be yielded after dur has passed.
sourcepub fn insert_at(&self, value: T, when: Instant) -> DelayHandle
pub fn insert_at(&self, value: T, when: Instant) -> DelayHandle
Inserts an item into the delay queue that will be yielded at when.