Struct futures_delay_queue::GenericSender
source · [−]pub struct GenericSender<MutexType, T, A> where
MutexType: RawMutex,
A: RingBuf<Item = T>,
T: 'static, { /* private fields */ }Expand description
The sending side of a channel which can be used to exchange values between concurrent tasks.
Values can be sent into the channel through send.
The returned Future will get resolved when the value has been stored inside the channel.
Implementations
sourceimpl<MutexType, T, A> GenericSender<MutexType, T, A> where
MutexType: 'static + RawMutex,
A: 'static + RingBuf<Item = T>,
impl<MutexType, T, A> GenericSender<MutexType, T, A> where
MutexType: 'static + RawMutex,
A: 'static + RingBuf<Item = T>,
sourcepub fn send(&self, value: T) -> ChannelSendFuture<MutexType, T>
pub fn send(&self, value: T) -> ChannelSendFuture<MutexType, T>
Returns a future that gets fulfilled when the value has been written to the channel. If the channel gets closed while the send is in progress, sending the value will fail, and the future will deliver the value back.
sourcepub fn try_send(&self, value: T) -> Result<(), TrySendError<T>>
pub fn try_send(&self, value: T) -> Result<(), TrySendError<T>>
Attempt to send the value without waiting.
This operation is not supported for unbuffered channels and will
panic if the capacity of the RingBuf is zero. The reason for this is
that the actual value transfer on unbuffered channels always happens
when a receiving task copies the value out of the sending task while it
is waiting. If the sending task does not wait, the value can not be
transferred. Since this method can therefore never yield a reasonable
result with unbuffered channels, it panics in order to highlight the
use of an inappropriate API.
sourcepub fn close(&self) -> CloseStatus
pub fn close(&self) -> CloseStatus
Closes the channel.
All pending future send attempts will fail.
Receive attempts will continue to succeed as long as there are items
stored inside the channel. Further attempts will return None.