Struct futures_delay_queue::DelayHandle [−][src]
pub struct DelayHandle { /* fields omitted */ }Expand description
A handle to cancel the corresponding delay of an item in DelayQueue.
Implementations
Resets the delay of the corresponding item to when and returns a new DelayHandle on
success.
Resets the delay of the corresponding item to now + dur and returns a new DelayHandleon
success.
Cancels the delay.